@@ -287,24 +287,28 @@ class Manager(manager.Manager):
             LOG.debug('Unable to validate token: %s', e)
             raise exception.TokenNotFound(token_id=token_id)
 
+    @MEMOIZE
+    def validate_non_persistent_token(self, token_id):
+        return self.driver.validate_non_persistent_token(token_id)
+
     @MEMOIZE
     def _validate_token(self, token_id):
         if not token_id:
             raise exception.TokenNotFound(_('No token in the request'))
 
-        if not self._needs_persistence:
-            # NOTE(lbragstad): This will validate v2 and v3 non-persistent
-            # tokens.
-            return self.driver.validate_non_persistent_token(token_id)
-        token_ref = self._persistence.get_token(token_id)
-        version = self.get_token_version(token_ref)
-        if version == self.V3:
-            try:
+        try:
+            if not self._needs_persistence:
+                # NOTE(lbragstad): This will validate v2 and v3 non-persistent
+                # tokens.
+                return self.driver.validate_non_persistent_token(token_id)
+            token_ref = self._persistence.get_token(token_id)
+            version = self.get_token_version(token_ref)
+            if version == self.V3:
                 return self.driver.validate_v3_token(token_ref)
-            except exception.Unauthorized as e:
-                LOG.debug('Unable to validate token: %s', e)
-                raise exception.TokenNotFound(token_id=token_id)
-        elif version == self.V2:
+        except exception.Unauthorized as e:
+            LOG.debug('Unable to validate token: %s', e)
+            raise exception.TokenNotFound(token_id=token_id)
+        if version == self.V2:
             return self.driver.validate_v2_token(token_ref)
         raise exception.UnsupportedTokenVersionException()
 
@@ -425,6 +429,10 @@ class Manager(manager.Manager):
         self._validate_token.invalidate(self, token_id)
         self._validate_v2_token.invalidate(self, token_id)
         self._validate_v3_token.invalidate(self, token_id)
+        # This method isn't actually called in the case of non-persistent
+        # tokens, but we include the invalidation in case this ever changes
+        # in the future.
+        self.validate_non_persistent_token.invalidate(self, token_id)
 
     def revoke_token(self, token_id, revoke_chain=False):
         revoke_by_expires = False
